import {Component, ElementRef, ViewChild} from '@angular/core';
import {IonicPage, NavController, NavParams} from 'ionic-angular';
import {SearchNewPage} from "../../home-pages/search-new/search-new";
import {TabsService} from "../tabs.service";
import {StuffDetailPage} from "../../home-pages/stuff-detail/stuff-detail";
import {PublishPage} from "../../discover-pages/publish/publish";
import {EmitService} from "../../../provide/emit.service";
import {NoticePage} from "../notice/notice";
import {AppGlobal} from "../../../service/http.service";


@IonicPage()
@Component({
    selector: 'page-discover',
    templateUrl: 'discover.html',
})
export class DiscoverPage {
    @ViewChild('tips') tips: ElementRef;
    @ViewChild('tabsParent') tabsParent: ElementRef;
    @ViewChild('tabsChildren') tabsChildren: ElementRef;
    @ViewChild('tabSpan') tabSpan: ElementRef;

    tabsList = [
        {name: "支部风采", type: 13, index: 0},
        {name: "机关党委", type: 5, index: 1},
        {name: "党风廉政", type: 9, index: 2},
        {name: "互动交流", type: -1, index: 3},
        {name: "知识拓展", type: -1, index: 4},
    ];
    index = 0;
    isSign = false;
    newList;   //新闻列表
    noReadNum;
    picture: string = AppGlobal.domain + '/wisdomgroup';

    constructor(public navCtrl: NavController, public navParams: NavParams,
                public tabsSer: TabsService, public emitSer: EmitService) {
        // 接收发射过来的数据
        this.emitSer.eventEmit.subscribe((value: any) => {
            if (!isNaN(value)) {
                this.noReadNum = value;
            }
        });
    }

    ionViewDidEnter() {
        this.change(this.tabsList[0]);
    }

    //所属板块类型:
    //1党章党规,2系列讲话,3中央精神,4本市部署,5通知公告,6党建动态,7工作提示,8党务参考
    //9廉政格言,10纪检提示,11风险排查,12警示教育,13支部活动,14党建联建,15结对帮扶
    change(item) {
        const index = item.index;
        let itemWidth = window.screen.width / 4;
        let spanWidth = this.tabSpan.nativeElement.offsetWidth;   //文字宽度
        this.tips.nativeElement.style.width = this.tabSpan.nativeElement.offsetWidth + 'px';
        // 自身div的一半 - 滑块的一半
        this.tips.nativeElement.style.left = itemWidth * (index) + (itemWidth - spanWidth) / 2 + 'px';
        this.index = index;
        const data = {
            pageSize: 1,
            pageCount: 100,
            obj: {
                'plateType': item.type,
                resourceType: 1
            }
        }
        this.tabsSer.stuffPage(data).subscribe(
            (res) => {
                this.newList = res.data;
                this.newList.forEach(e => {
                    if (e.attachments.length > 0) {
                        e.imgUrl = e.attachments[0].path;
                    }
                })
            }
        )
    }


    //前往搜索页面
    goToSearch() {
        this.navCtrl.push(SearchNewPage);
    }

    //查看详情
    goToDetail(item) {
        this.navCtrl.push(StuffDetailPage, {
            id: item.id
        });
    }

    //前往发布页面
    goToPublish() {
        this.navCtrl.push(PublishPage);
    }

    //消息提醒页面
    goToNotice() {
        this.navCtrl.push(NoticePage);
    }

}
