import {Component, ElementRef, ViewChild} from '@angular/core';
import {NavController, IonicPage, Slides} from 'ionic-angular';
import {ActivityListPage} from "../../home/activity/activityList/activityList";
import {Http, Response} from '@angular/http';
import {AppService, AppGlobal} from '../../../service/http.service';
import {Calendar} from '@ionic-native/calendar';
import {ActivityApplyPage} from "../../home/activity/activityApply/activityApply";
import {ActivityDetailPage} from "../../home/activity/activityDetail/activityDetail";
import {OutGoingReportPage} from "../../home/report/outGoingReport/outGoingReport";
import {AnnouncementPage} from '../../home/announcement/announcementList/announcement';
import {Storage} from '@ionic/storage';
import {OutGoingReportEditPage} from "../../home/report/outGoingReportEdit/outGoingReportEdit";
import {AnnouncementViewPage} from '../../home/announcement/announcementView/announcementView';
import {CalendarComponentOptions, DayConfig} from "ion2-calendar";
import {NoticePage} from "../notice/notice";
import {Badge} from '@ionic-native/badge';
import {TabsService} from "../tabs.service";
import {TextToSpeech} from "@ionic-native/text-to-speech";
import {CommonService} from "../../../provide/common.service";
import {SearchNewPage} from "../../home-pages/search-new/search-new";
import {StuffDetailPage} from "../../home-pages/stuff-detail/stuff-detail";
import {EmitService} from "../../../provide/emit.service";

declare var Swiper;

@IonicPage()
@Component({
    selector: 'page-home',
    templateUrl: 'home.html'
})

export class HomePage {
    @ViewChild(Slides) slides: Slides;
    @ViewChild('tips') tips: ElementRef;
    @ViewChild('lineChangeEle') lineChangeEle: ElementRef;
    @ViewChild('tabSpan') tabSpan: ElementRef;

    picture: string = AppGlobal.domain + '/wisdomgroup';
    slidersItems = [];
    //所属板块类型:
    //1党章党规,2系列讲话,3中央精神,4本市部署,5通知公告,6党建动态,7工作提示,8党务参考
    //9廉政格言,10纪检提示,11风险排查,12警示教育,13支部活动,14党建联建,15结对帮扶
    tabsList = [
        {name: "系列讲话", type: 2,index:0},
        {name: "党章党规", type: 1,index:1},
        {name: "中央精神", type: 3,index:2},
        {name: "本市部署", type: 4,index:3}
        ];
    index = 0;
    isSign = false;

    newList = [];
    noReadNum;

    signObj = {
        'text': '',
        'isSign': ''
    };   //签到参数
    disabledClick = true;
    signText;   //签到倒计时
    partyObj;  //政治生日

    slideTitle;

    move_h = 33;     //移动高度
    scorllStep = 1;
    scrollTime = 60;
    stopTime = 1000;
    tmpH = 0;


    constructor(public navCtrl: NavController, public tts: TextToSpeech,
                public commonSer: CommonService, public emitSer: EmitService,
                public appService: AppService, public http: Http, public storage: Storage,
                public badge: Badge, public tabsSer: TabsService) {
        // 接收发射过来的数据
        this.emitSer.eventEmit.subscribe((value: any) => {
            if (!isNaN(value)) {
                this.noReadNum = value;
            }
        });

    }

    lineChange() {
        let child_div = this.lineChangeEle.nativeElement.children;
        setTimeout(() => {
            if (child_div.length > 0) {
                this.start();
            }
        }, 10);

    }

    start() {
        if (this.tmpH < this.move_h) {//  tmpH = 0 ; move_h = 33
            this.tmpH += this.scorllStep;//scorllStep = 1
            if (this.tmpH > this.move_h) {
                this.tmpH = this.move_h;
            }
            this.lineChangeEle.nativeElement.scrollTop = this.tmpH;
            setTimeout(() => {
                this.start()
            }, this.scrollTime);//stopTime = 3000 ; scrollTime = 30 每移动一个单位延时30ms
        } else {
            this.tmpH = 0;
            this.lineChangeEle.nativeElement.appendChild(this.lineChangeEle.nativeElement.children[0]);
            // this.lineChangeEle.nativeElement.scrollTop = 0;
            setTimeout(() => {
                this.start()
            }, this.stopTime);//stopTime = 3000 ; scrollTime = 30 每移动一个单位延时30ms
        }
    }


    ionViewDidLoad() {
        this.tabsSer.signNow().subscribe(
            (res) => {
                this.signObj = res.data;
            }
        );
        this.change(this.tabsList[0]);
        this.getBanner();
        this.getInfo();
        this.lineChange();
    }

    //获取轮播图
    getBanner() {
        const data = {
            obj: {
                resourceType: 2,
                isRecommend: 1,
            }
        }
        this.tabsSer.stuffPage(data).subscribe(
            (res) => {
                this.slidersItems = res.data;
                this.slidersItems.forEach(e => {
                    if (e.title.length > 16) {
                        e.title = e.title.substr(0, 14) + '...';
                    }
                    if (e.attachments.length > 0) {
                        e.imgUrl = e.attachments[0].path;
                    }
                })
            }
        )
    }

    //slideChange
    slideChange(e) {
        let index = this.slides.getActiveIndex();
        if (index == this.slidersItems.length + 1) index = 1
        this.slideTitle = this.slidersItems[index - 1].title;
    }

    //获取党员生日
    getInfo() {
        this.storage.get("userLoginInfo").then((value) => {
            let userid = value.userid;
            this.tabsSer.getInfo(userid).subscribe(
                (res) => {
                    this.partyObj = res.apiResult.data;
                }
            );
        })
    }

    //所属板块类型(1党规党章,2系列讲话,3中央精神,4本市部署,5通知公告,6党建动态,7工作提示,
    //      * 8党务参考,9廉政格言,10纪检提示,11风险排查,12警示教育,13支部活动,14党建联建,15结对帮扶)
    change(item) {
        const index = item.index;
        let itemWidth = window.screen.width / 4;
        let spanWidth = this.tabSpan.nativeElement.offsetWidth;   //文字宽度
        this.tips.nativeElement.style.width = this.tabSpan.nativeElement.offsetWidth + 'px';
        // 自身div的一半 - 滑块的一半
        this.tips.nativeElement.style.left = itemWidth * (index) + (itemWidth - spanWidth) / 2 + 'px';
        this.index = index;
        const data = {
            pageSize: 1,
            pageCount: 100,
            obj: {
                'plateType': index,
                'resourceType': 1
            }
        }
        this.tabsSer.stuffPage(data).subscribe(
            (res) => {
                this.newList = res.data;
                this.newList.forEach(e => {
                    if (e.attachments.length > 0) {
                        e.imgUrl = e.attachments[0].path;
                    }
                })
            }
        )
    }

    //签到
    signUp() {
        this.signObj.isSign = 'yes';
        this.tabsSer.sign().subscribe(
            (res) => {
                this.isSign = false;
                if (res.errcode == '1000') {
                    this.commonSer.toast('签到成功');
                } else {
                    this.commonSer.toast(res.errmsg);
                }
            }
        )
    }

    //签到
    signNow() {
        this.isSign = true;
        let totalTime = 5;
        this.signText = '(倒计时' + totalTime + 's)';
        let clock = window.setInterval(() => {
            totalTime--;
            this.signText = '(倒计时' + totalTime + 's)';
            if (totalTime < 0) {
                this.signText = '';
                window.clearInterval(clock);
                this.disabledClick = false;
            }
        }, 1000)
    }

    //查看文章详情
    goToDetail(item) {
        this.navCtrl.push(StuffDetailPage, {
            id: item.id
        })
    }

    //前往搜索页面
    goToSearch() {
        this.navCtrl.push(SearchNewPage);
    }


    //消息提醒页面
    goToNotice() {
        this.navCtrl.push(NoticePage);
    }

}
